@@ -2,13 +2,14 @@
 """ This module is named python module.py and bring you function print_lol. In this function, you can find list
       type element and show them as data."""
 
-def print_lol(the_list, indent=False, level=0) :
+import sys
+def print_lol(the_list, indent=False, level=0, fh=sys.stdout) :
     for each_item in the_list :
         if isinstance(each_item, list) :
-            print_lol(each_item, indent, level + 1)
+            print_lol(each_item, indent, level + 1, fh)
         else :
             if indent :
                 for tab_stop in range(level) :
-                    print("\t",end='')
-            print(each_item)
+                    print("\t",end='', file=fh)
+            print(each_item, file=fh)
 
